/************************************************************************/
/*																		*/
/*	SWT.cpp		--		Definition for SWT library 	  			  		*/
/*																		*/
/************************************************************************/
/*	Author:		Eric Marsh												*/
/*	Copyright 2016, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This file defines functions for the PmodSWT						*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	07/27/2016(EricM): created											*/
/*																		*/
/************************************************************************/


/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include "SWT.h"
#include <WProgram.h>


/* ------------------------------------------------------------ */
/*				Procedure Definitions							*/
/* ------------------------------------------------------------ */

/* ------------------------------------------------------------ */
/*        SWT::SWT
**
**        Synopsis:
**				
**        Parameters:
**
**
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Class constructor. Performs variables initialization tasks
**
**
*/
SWT::SWT()
{
	SWT1 = -1;
	SWT2 = -1;
	SWT3 = -1;
	SWT4 = -1;
}

/* ------------------------------------------------------------ */
/*        SWT::begin
**
**        Synopsis:
**				SWT.begin(10, 11, 12, 13);
**        Parameters:
**				- int SWT1 - pin # of switch 1
**				- int SWT2 - pin # of switch 2
**				- int SWT3 - pin # of switch 3
**				- int SWT4 - pin # of switch 4
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				This function initializes the switch pins to utilize PmodSWT
**
**
*/
void SWT::begin(int SW0, int SW1, int SW2, int SW3)
{
	SWT1 = SW0;
	SWT2 = SW1;
	SWT3 = SW2;
	SWT4 = SW3;
	
	pinMode(SWT1, INPUT);
	pinMode(SWT2, INPUT);
	pinMode(SWT3, INPUT);
	pinMode(SWT4, INPUT);
}

/* ------------------------------------------------------------ */
/*        SWT::GetSwitchPin
**
**        Synopsis:
**				SWT.GetSwitchPin(1);
**        Parameters:
**				None
**
**        Return Values:
**              int - pin # of the switch listed in the parameter
**
**        Errors:
**
**
**        Description:
**				Returns the pin # of the switch listed in the parameter.
**
**
*/
int SWT::GetSwitchPin(int SW)
{
	if(SW > 3 || SW < 0 || SWT1 == -1){
		return -1;
	}
	switch(SW){
		case 0:
			return SWT1;
		case 1:
			return SWT2;
		case 2:
			return SWT3;
		case 3:
			return SWT4;
		default:
			return -1;
	
	}
}

/* ------------------------------------------------------------ */
/*        SWT::GetStatus
**
**        Synopsis:
**				SWT.GetStatus(1);
**        Parameters:
**				- int SW - pin # of switch to check
**
**        Return Values:
**                bool - if switch is on or not 
**
**        Errors:
**
**
**        Description:
**				This function checks the switch number to see if it's activated or not.
**
**
*/
bool SWT::GetStatus(int SW)
{
	int switchPin = GetSwitchPin(SW);
	return digitalRead(switchPin);
}

/* ------------------------------------------------------------ */
/*        SWT::AllOn
**
**        Synopsis:
**				SWT.AllOn();
**        Parameters:
**				None
**
**        Return Values:
**              bool - if all switches are on.  
**
**        Errors:
**
**
**        Description:
**				Returns if all switches are on.
**
**
*/
bool SWT::AllOn()
{
	return ( digitalRead(GetSwitchPin(0)) && digitalRead(GetSwitchPin(1)) && digitalRead(GetSwitchPin(2)) && digitalRead(GetSwitchPin(3)));
}

/* ------------------------------------------------------------ */
/*        SWT::AllOff
**
**        Synopsis:
**				SWT.AllOff();
**        Parameters:
**				None
**
**        Return Values:
**              bool - if all switches are off.  
**
**        Errors:
**
**
**        Description:
**				Returns if all switches are off.
**
**
*/
bool SWT::AllOff()
{
	return ( !digitalRead(GetSwitchPin(0)) && !digitalRead(GetSwitchPin(1)) && !digitalRead(GetSwitchPin(2)) && !digitalRead(GetSwitchPin(3)));
}